==> jc-1.4.0.tar.gz: soot/grimp/internal/GLengthExpr.h <==
// public class soot.grimp.internal.GLengthExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 226105a417da513e soot_grimp_internal_GLengthExpr
// @dep_class d3526440663c1839 soot_jimple_internal_AbstractLengthExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractLengthExpr

#include "soot/jimple/internal/AbstractLengthExpr.h"

#ifndef _JC_soot_grimp_internal_GLengthExpr_H_
#define _JC_soot_grimp_internal_GLengthExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GLengthExpr$sub_refs	_jc_soot_grimp_internal_GLengthExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GLengthExpr$sub_nonrefs	_jc_soot_grimp_internal_GLengthExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GLengthExpr$refs	_jc_soot_grimp_internal_GLengthExpr$refs;
typedef struct _jc_soot_grimp_internal_GLengthExpr$nonrefs	_jc_soot_grimp_internal_GLengthExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GLengthExpr$object	_jc_soot_grimp_internal_GLengthExpr$object;

typedef const struct _jc_soot_grimp_internal_GLengthExpr$vmethods	_jc_soot_grimp_internal_GLengthExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GLengthExpr$vtable	_jc_soot_grimp_internal_GLengthExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GLengthExpr$vtype	_jc_soot_grimp_internal_GLengthExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GLengthExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GLengthExpr$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GLengthExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GLengthExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GLengthExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GLengthExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GLengthExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GLengthExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractLengthExpr$vmethods	soot_jimple_internal_AbstractLengthExpr;
	_jc_soot_grimp_internal_GLengthExpr$vmethods	soot_grimp_internal_GLengthExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GLengthExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GLengthExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLengthExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GLengthExpr$refs {
    _jc_soot_grimp_internal_GLengthExpr$sub_refs	soot_grimp_internal_GLengthExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_refs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLengthExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GLengthExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_nonrefs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_grimp_internal_GLengthExpr$sub_nonrefs	soot_grimp_internal_GLengthExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GLengthExpr$object {
	_jc_soot_grimp_internal_GLengthExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GLengthExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GLengthExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GLengthExpr$vtype _jc_soot_grimp_internal_GLengthExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GLengthExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GLengthExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GLengthExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GLengthExpr.h <==
// public class soot.grimp.internal.GLengthExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 226105a417da513e soot_grimp_internal_GLengthExpr
// @dep_class d3526440663c1839 soot_jimple_internal_AbstractLengthExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractLengthExpr

#include "soot/jimple/internal/AbstractLengthExpr.h"

#ifndef _JC_soot_grimp_internal_GLengthExpr_H_
#define _JC_soot_grimp_internal_GLengthExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GLengthExpr$sub_refs	_jc_soot_grimp_internal_GLengthExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GLengthExpr$sub_nonrefs	_jc_soot_grimp_internal_GLengthExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GLengthExpr$refs	_jc_soot_grimp_internal_GLengthExpr$refs;
typedef struct _jc_soot_grimp_internal_GLengthExpr$nonrefs	_jc_soot_grimp_internal_GLengthExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GLengthExpr$object	_jc_soot_grimp_internal_GLengthExpr$object;

typedef const struct _jc_soot_grimp_internal_GLengthExpr$vmethods	_jc_soot_grimp_internal_GLengthExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GLengthExpr$vtable	_jc_soot_grimp_internal_GLengthExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GLengthExpr$vtype	_jc_soot_grimp_internal_GLengthExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GLengthExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GLengthExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GLengthExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GLengthExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GLengthExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GLengthExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GLengthExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GLengthExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractLengthExpr$vmethods	soot_jimple_internal_AbstractLengthExpr;
	_jc_soot_grimp_internal_GLengthExpr$vmethods	soot_grimp_internal_GLengthExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GLengthExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GLengthExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLengthExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GLengthExpr$refs {
    _jc_soot_grimp_internal_GLengthExpr$sub_refs	soot_grimp_internal_GLengthExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_refs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLengthExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GLengthExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractLengthExpr$sub_nonrefs	soot_jimple_internal_AbstractLengthExpr;
    _jc_soot_grimp_internal_GLengthExpr$sub_nonrefs	soot_grimp_internal_GLengthExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GLengthExpr$object {
	_jc_soot_grimp_internal_GLengthExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GLengthExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GLengthExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GLengthExpr$vtype _jc_soot_grimp_internal_GLengthExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GLengthExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GLengthExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GLengthExpr_H_ */
